#! /usr/bin/python3
## This script reads out different temperature sensors and write them to a daily file
## Temperature sensors of type Dallas DS18B20, single wire interface have to be connected to
## GPIO #4 (BCM Numbering) with en external 4k7 Ohm resistor to +3.3V
## Written by Yves OESCH
##
## History:
## Temp_01.py : 7.9.2016
##
import os
import datetime

sensors_path='/sys/bus/w1/devices/'
sensors_fname='/w1_slave'



sensors_list=(('Temperature exterieure','28-021564aea9ff'),
              ('Depart Boiler','28-021564ae72ff'),
              ('Depart Chauffage','28-021564b6b6ff'),
              ('Retour','28-031564aaafff'))

strOutputDir='/home/pi/Temperature/'
strOutputFile='Temperatures.log'
strSeparator=';'

def readOneSensor(serialNumber):
## Self explaining... path to sensor is hardcoded below
    
    tFileNameFull=sensors_path+serialNumber+sensors_fname
    if os.path.isfile(tFileNameFull)==True:
        tfile = open(tFileNameFull)
        # Read all of the text in the file.
        text = tfile.read()
        # Close the file now that the text has been read.
        tfile.close()
        # Split the text with new lines (\n) and select the second line.
        secondline = text.split("\n")[1]
        # Split the line into words, referring to the spaces, and select the 10th word (counting from 0).
        temperaturedata = secondline.split(" ")[9]
        # The first two characters are "t=", so get rid of those and convert the temperature from a string to a number.
        temperature = float(temperaturedata[2:])
        # Put the decimal point in the right place and display it.
        temperature = temperature / 1000
        #print(serialNumber,':',temperature,'°C')

    else:                       ## Wrong temperature sensor number
        temperature='NaN'
        print('Temperature seosor file does not exist:',tFileNameFull )
    return(temperature)





now=datetime.datetime.now()
strDate=str(now.strftime('%Y_%m_%d'))
strTime=str(now.strftime('%H:%M:%S'))

strFullFileName=strOutputDir+strDate+'_'+strOutputFile
print(strFullFileName)

if os.path.isfile(strFullFileName)==False:          #create file and header if daily file not existing
    print('LogFile does not exist, creating file')  #Date;Time;Sensors...
    logfile=open(strFullFileName,'w')
    logfile.write(
        'Date'+strSeparator
        +'Heure'+strSeparator)
    for sensor in sensors_list:
        logfile.write(sensor[0]+strSeparator)
    logfile.write('\n')
    logfile.close()

print('Logfile exists: appending data')             #Write date to file
logfile=open(strFullFileName,'a')
logfile.write(
    strDate+strSeparator
    +strTime+strSeparator)
for sensor in sensors_list:
    strTemperature=str(readOneSensor(sensor[1]))
    logfile.write(strTemperature+strSeparator)
    print(sensor[0],':',strTemperature)
logfile.write('\n')
logfile.close()

print('***** The END ******')
